==> danse-2.2.0.tar.gz: danse/modules/form/src/Payload.php <==
<?php

namespace Drupal\danse_form;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\danse\Entity\Event;
use Drupal\danse\Entity\EventInterface;
use Drupal\danse\PayloadBase;
use Drupal\danse\PayloadInterface;

/**
 * Class Payload.
 *
 * @package Drupal\danse_form
 */
final class Payload extends PayloadBase {

  /**
   * @var array
   */
  protected $form;

  /**
   * @var \Drupal\Core\Form\FormStateInterface
   */
  protected $form_state;

  /**
   * Content constructor.
   *
   * @param array $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   */
  public function __construct(array $form, FormStateInterface $form_state) {
    $this->form = $form;
    $this->form_state = $form_state;
  }

  /**
   * {@inheritdoc}
   */
  public function label(): string {
    return $this->form['#form_id'];
  }

  /**
   * {@inheritdoc}
   */
  public function getEventReference(): string {
    return implode('-', ['form', $this->form['#form_id']]);
  }

  /**
   * {@inheritdoc}
   */
  public function getSubscriptionReferences(EventInterface $event): array {
    return [implode('-', ['form', $event->getTopic()])];
  }

  /**
   * {@inheritdoc}
   */
  public function prepareArray(): array {
    return [
      'form' => $this->form,
      'form_state' => serialize($this->form_state),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function createFromArray(array $payload): PayloadInterface {
    return new static($payload['form'], unserialize($payload['form_state'], ['allowed_classes' => ['Drupal\Core\Form\FormState']]));
  }

  /**
   * {@inheritdoc}
   */
  public function getEntity(): ContentEntityInterface {
    /** @var Event $entity */
    $entity = Event::create([
      'plugin' => 'form',
      'topic' => '',
      'label' => '',
      'payload' => $this,
      'push' => TRUE,
      'force' => FALSE,
      'silent' => FALSE,
    ]);
    return $entity;
  }

  /**
   * {@inheritdoc}
   */
  public function hasAccess($uid): bool {
    return FALSE;
  }

}

==> danse-2.2.7.tar.gz: danse/modules/form/src/Payload.php <==
<?php

namespace Drupal\danse_form;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\danse\Entity\Event;
use Drupal\danse\Entity\EventInterface;
use Drupal\danse\PayloadBase;
use Drupal\danse\PayloadInterface;
use Drupal\Core\Form\FormState;

/**
 * Class Payload.
 *
 * @package Drupal\danse_form
 */
final class Payload extends PayloadBase {

  /**
   * @var array
   */
  protected $form;

  /**
   * @var \Drupal\Core\Form\FormStateInterface
   */
  protected $form_state;

  /**
   * Content constructor.
   *
   * @param array $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   */
  public function __construct(array $form, FormStateInterface $form_state) {
    $this->form = $form;
    $this->form_state = $form_state;
  }

  /**
   * {@inheritdoc}
   */
  public function label(Event $event): string {
    return $this->form['#form_id'];
  }

  /**
   * {@inheritdoc}
   */
  public function getEventReference(): string {
    return implode('-', ['form', $this->form['#form_id']]);
  }

  /**
   * {@inheritdoc}
   */
  public function getSubscriptionReferences(EventInterface $event): array {
    return [implode('-', ['form', $event->getTopic()])];
  }

  /**
   * {@inheritdoc}
   */
  public function prepareArray(): array {
    return [
      'form' => $this->form,
      'form_state' => serialize($this->form_state),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function createFromArray(array $payload): ?PayloadInterface {
    return new Payload($payload['form'], unserialize($payload['form_state'], ['allowed_classes' => [FormState::class]]));
  }

  /**
   * {@inheritdoc}
   */
  public function getEntity(): ContentEntityInterface {
    /** @var Event $entity */
    $entity = Event::create([
      'plugin' => 'form',
      'topic' => '',
      'label' => '',
      'payload' => $this,
      'push' => TRUE,
      'force' => FALSE,
      'silent' => FALSE,
    ]);
    return $entity;
  }

  /**
   * {@inheritdoc}
   */
  public function hasAccess($uid): bool {
    return FALSE;
  }

}
